@@ -1,4 +1,4 @@
-from ccc.coef.impl import *
+from ccc.coef.impl import *  # noqa: F403, F401
 
 try:
     # Run CCC to initialize/compile its functions with numba
